@@ -3,7 +3,7 @@ package Assert::Refute::Exec;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.08;
+our $VERSION = 0.03;
 
 =head1 NAME
 
@@ -27,9 +27,9 @@ See L<Assert::Refute::Contract> for contract I<definition>.
     # .......
     $c->done_testing; # no more refute after this
 
-    $c->get_count;    # how many tests were run
-    $c->is_passing;   # did any of them fail?
-    $c->get_tap;      # return printable summary in familiar format
+    $c->count;      # how many tests were run
+    $c->is_passing; # did any of them fail?
+    $c->as_tap;     # return printable summary in familiar format
 
 =cut
 
@@ -53,7 +53,7 @@ my $ERROR_DONE = "done_testing was called, no more changes may be added";
 
 =over
 
-=item * indent - log indentation (will be shown as 4 spaces in C<get_tap>);
+=item * indent - log indentation (will be shown as 4 spaces in C<as_tap>);
 
 =back
 
@@ -87,14 +87,14 @@ sub refute {
 
     $msg = $msg ? " - $msg" : '';
     my $n = ++$self->{count};
+    $self->add_result( $n, $cond );
 
     if ($cond) {
-        $self->set_result( $n, $cond );
-        $self->do_log( 0, -1, "not ok $n$msg" );
-        $self->do_log( 0,  1, $cond ) unless $cond eq 1;
+        $self->log_message( 0, -1, "not ok $n$msg" );
+        $self->log_message( 0,  1, $cond ) unless $cond eq 1;
         return 0;
     } else {
-        $self->do_log( 0,  0, "ok $n$msg" );
+        $self->log_message( 0,  0, "ok $n$msg" );
         return 1;
     };
 };
@@ -118,13 +118,13 @@ References are explained to depth 1.
 sub diag {
     my $self = shift;
 
-    $self->do_log( 0, 1, join " ", map { to_scalar($_) } @_ );
+    $self->log_message( 0, 1, join " ", map { to_scalar($_) } @_ );
 };
 
 sub note {
     my $self = shift;
 
-    $self->do_log( 0, 2, join " ", map { to_scalar($_) } @_ );
+    $self->log_message( 0, 2, join " ", map { to_scalar($_) } @_ );
 };
 
 =head3 done_testing
@@ -134,19 +134,10 @@ After this call, no more writes (including done_testing)
 can be performed on this contract.
 This happens by default at the end of C<contract{ ... }> block.
 
-Dies if called for a second time, I<unless> an argument is given.
-
-A true argument is considered to be the exception
+If an argument is given, it is considered to be the exception
 that interrupted the contract execution,
 resulting in an unconditionally failed contract.
 
-A false argument just avoids dying and is equivalent to
-
-    $report->done_testing
-        unless $report->is_done;
-
-Returns self.
-
 =cut
 
 sub done_testing {
@@ -154,19 +145,18 @@ sub done_testing {
 
     if ($exception) {
         delete $self->{done};
-        $self->{has_error} = $exception;
+        $self->{last_error} = $exception;
         # Make sure there *is* a failing test on the outside
         $self->refute( $exception, "unexpected exception: $exception" );
-        $self->do_log( 0, 1, "Looks like test execution was interrupted" );
+        $self->log_message( 0, 1, "Looks like test execution was interrupted" );
     } elsif ($self->{done}) {
-        return $self if defined $exception;
-        $self->_croak( $ERROR_DONE );
+        $self->_croak( $ERROR_DONE )
     } else {
-        $self->do_log(0, 0, "1..$self->{count}");
+        $self->log_message(0, 0, "1..$self->{count}");
     };
-    $self->do_log(0, 1,
-        "Looks like $self->{fail_count} tests of $self->{count} have failed")
-            if $self->{fail_count};
+    $self->log_message(0, 1,
+        "Looks like $self->{failed} tests of $self->{count} have failed")
+            if $self->{failed};
 
     $self->{done}++;
     return $self;
@@ -193,20 +183,7 @@ will be added to this L<Assert::Refute::Exec> by default.
 
 =head3 subcontract( "Message" => $specification, @arguments ... )
 
-Execute a previously defined group of tests and fail loudly if it fails.
-
-$specification may be one of:
-
-=over
-
-=item * code reference - will be executed in C<eval> block, with a I<new>
-L<Assert::Refute::Exec> passed as argument;
-
-=item * L<Assert::Refute::Contract> instance - apply() will be called;
-
-=item * L<Assert::Refute::Exec> instance implying a previously executed test.
-
-=back
+Execute a previously defined contract and fail loudly if it fails.
 
 B<[NOTE]> that the message comes first, unlike in C<refute> or other
 test conditions, and is required.
@@ -214,38 +191,14 @@ test conditions, and is required.
 =cut
 
 sub subcontract {
-    my ($self, $msg, $sub, @args) = @_;
+    my ($self, $msg, $c, @args) = @_;
 
-    my $rep;
-    if ( blessed $sub and $sub->isa( "Assert::Refute::Contract" ) ) {
-        $rep = $sub->apply(@args);
-    } elsif (blessed $sub and $sub->isa( "Assert::Refute::Exec" ) ) {
-        $self->_croak("pre-executed subcontract cannot take args")
-            if @args;
-        $self->_croak("pre-executed subcontract must be finished")
-            unless $sub->is_done;
-        $rep = $sub;
-    } elsif (UNIVERSAL::isa( $sub, 'CODE' )) {
-        $rep = Assert::Refute::Exec->new;
-        local $Assert::Refute::DRIVER = $rep;
-        eval {
-            $sub->($rep, @args);
-            $rep->done_testing(0);
-            1;
-        } or do {
-            $rep->done_testing( $@ || "Execution interrupted" );
-        };
-    } else {
-        $self->_croak("subcontract must be a contract definition or execution log");
-    };
+    $self->_croak("subcontract must be a contract definition or execution log")
+        unless blessed $c;
 
-    my $stop = !$rep->is_passing;
+    my $log = $c->isa("Assert::Refute::Contract") ? $c->apply(@args) : $c;
+    my $stop = !$log->is_passing && $log->as_tap;
     $self->refute( $stop, "$msg (subtest)" );
-    if ($stop) {
-        my $log = $rep->get_log;
-        $self->do_log( $_->[0]+1, $_->[1], $_->[2] )
-            for @$log;
-    };
 };
 
 =head2 QUERYING PRIMITIVES
@@ -271,31 +224,20 @@ Tell whether the contract is passing or not.
 sub is_passing {
     my $self = shift;
 
-    return !$self->{fail_count} && !$self->{has_error};
+    return !$self->{failed} && !$self->{last_error};
 };
 
-=head3 get_count
+=head3 count
 
 How many tests have been executed.
 
 =cut
 
-sub get_count {
+sub count {
     my $self = shift;
     return $self->{count};
 };
 
-=head3 get_fail_count
-
-How many tests failed
-
-=cut
-
-sub get_fail_count {
-    my $self = shift;
-    return $self->{fail_count} || 0;
-};
-
 =head3 get_tests
 
 Returns a list of test ids, preserving order.
@@ -304,10 +246,10 @@ Returns a list of test ids, preserving order.
 
 sub get_tests {
     my $self = shift;
-    return 1 .. $self->{count};
+    return $self->{list} ? @{ $self->{list} } : ();
 };
 
-=head3 get_result( $id )
+=head3 result( $id )
 
 Returns result of test denoted by $id, dies if such test was never performed.
 The result is false for passing tests and whatever the reason for failure was
@@ -315,36 +257,43 @@ for failing ones.
 
 =cut
 
-sub get_result {
+sub result {
     my ($self, $n) = @_;
 
-    return $self->{fail}{$n} || 0
-        if exists $self->{fail}{$n};
+    $self->_croak( "Test $n has never been performed" )
+        unless exists $self->{fail}{$n};
 
-    return 0 if $n =~ /^[1-9]\d*$/ and $n<= $self->{count};
-
-    $self->_croak( "Test $n has never been performed" );
+    return $self->{fail}{$n} || 0;
 };
 
-=head3 get_error
+=head3 has_died
+
+Returns true if contract execution was ever interrupted by exception.
+
+=cut
+
+# TODO like, do we need this if we have last_error?
+*has_died = *has_died = \&last_error;
+
+=head3 last_error
 
 Return last error that was recorded during contract execution,
 or false if there was none.
 
 =cut
 
-sub get_error {
+sub last_error {
     my $self = shift;
-    return $self->{has_error} || '';
+    return $self->{last_error} || '';
 };
 
-=head3 get_tap
+=head3 as_tap
 
 Return a would-be Test::More script output for current contract.
 
 =cut
 
-sub get_tap {
+sub as_tap {
     my ($self, $verbosity) = @_;
 
     $verbosity = 1 unless defined $verbosity;
@@ -364,10 +313,9 @@ sub get_tap {
     return join '', @str;
 };
 
-=head3 get_sign
+=head3 signature
 
-Produce a terse pass/fail summary (signature)
-as a string of numbers and letters.
+Produce a terse pass/fail summary as a string of numbers and letters.
 
 The format is C<"t(\d+|N)*[rdE]">.
 
@@ -395,7 +343,7 @@ The numeric notation was inspired by Forsyth-Edwards notation (FEN) in chess.
 
 =cut
 
-sub get_sign {
+sub signature {
     my $self = shift;
 
     my @t = ("t");
@@ -412,53 +360,28 @@ sub get_sign {
     };
     push @t, $streak if $streak;
 
-    my $d = $self->get_error ? 'E' : $self->{done} ? 'd' : 'r';
+    my $d = $self->last_error ? 'E' : $self->{done} ? 'd' : 'r';
     return join '', @t, $d;
 };
 
+sub _croak {
+    my ($self, $mess) = @_;
+    my @where = caller 0;
+
+    my $fun = $where[3];
+    $fun =~ s/.*:://;
+    $mess ||= "Something terrible happened";
+    $mess =~ s/\n+$//s;
+
+    croak "$where[0]->$fun: $mess";
+};
+
 =head2 DEVELOPMENT PRIMITIVES
 
 Generally one should not touch these methods unless
 when subclassing to build a new test backend.
 
-When extending this module,
-please try to stick to C<do_*>, C<get_*>, and C<set_*>
-to avoid clash with test names.
-
-This is weird and probably has to be fixed at some point.
-
-=head3 do_run( $code, @list )
-
-Run given CODEREF, passing self as both first argument I<and>
-current_contract().
-Report object is locked afterwards via L</done_testing> call.
-
-Returns self.
-
-Example usage is
-
-    Assert::Refute::Exec->new->run( sub {
-        like $this, qr/.../;
-        can_ok $that, qw(foo bar frobnicate);
-    } );
-
-=cut
-
-sub do_run {
-    my ($self, $code, @args) = @_;
-    local $Assert::Refute::DRIVER = $self;
-    eval {
-        $code->($self, @args);
-        $self->done_testing(0);
-        1;
-    } || do {
-        $self->done_testing(
-            $@ || Carp::shortmess( 'Contract execution interrupted' ) );
-    };
-    return $self;
-};
-
-=head3 do_log( $indent, $level, $message )
+=head3 log_message( $indent, $level, $message )
 
 Append a message to execution log.
 Levels are:
@@ -479,45 +402,28 @@ Levels are:
 
 =cut
 
-sub do_log {
-    my ($self, $indent, $level, $mess) = @_;
+sub log_message {
+    my ($self, $indent, $level, @parts) = @_;
 
     $self->_croak( $ERROR_DONE )
         if $self->{done};
 
     $indent += $self->{indent};
 
-    push @{ $self->{mess} }, [$indent, $level, $mess];
+    foreach (@parts) {
+        push @{ $self->{mess} }, [$indent, $level, $_];
+    };
 
     return $self;
 };
 
-=head2 get_log
-
-Return log messages "as is" as array reference
-containing triads of (indent, level, message).
-
-B<[CAUTION]> This currently returns reference to internal structure,
-so be careful not to spoil it.
-This MAY change in the future.
-
-=cut
-
-sub get_log {
-    my $self = shift;
-    # TODO copy or smth
-    return $self->{mess};
-};
-
-=head3 set_result( $id, $result )
+=head3 add_result( $id, $result )
 
 Add a refutation to the failed tests log.
 
-This is not guaranteed to be called for passing tests.
-
 =cut
 
-sub set_result {
+sub add_result {
     my ($self, $id, $result) = @_;
 
     $self->_croak( $ERROR_DONE )
@@ -525,7 +431,8 @@ sub set_result {
     $self->_croak( "Duplicate test id $id" )
         if exists $self->{fail}{$id};
 
-    $self->{fail_count}++ if $result;
+    push @{ $self->{list} }, $id;
+    $self->{failed}++ if $result;
     $self->{fail}{$id} = $result;
 
     return $self;
@@ -543,65 +450,6 @@ sub get_proxy {
     return wantarray ? ($self, $self->{indent}) : $self;
 };
 
-sub _croak {
-    my ($self, $mess) = @_;
-
-    $mess ||= "Something terrible happened";
-    $mess =~ s/\n+$//s;
-
-    my $fun = (caller 1)[3];
-    $fun =~ s/(.*)::/${1}->/;
-
-    croak "$fun(): $mess";
-};
-
-=head2 DEPRECATED METHODS
-
-The following methods were added in the beginning and will disappear
-in 0.10.
-
-=over
-
-=item count       => "get_count"
-
-=item add_result  => "set_result"
-
-=item result      => "get_result"
-
-=item last_error  => "get_error"
-
-=item signature   => "get_sign"
-
-=item as_tap      => "get_tap"
-
-=item log_message => "do_log"
-
-=back
-
-=cut
-
-_deprecate( count       => "get_count" );
-_deprecate( add_result  => "set_result" );
-_deprecate( result      => "get_result" );
-_deprecate( last_error  => "get_error" );
-_deprecate( signature   => "get_sign" );
-_deprecate( as_tap      => "get_tap" );
-_deprecate( log_message => "do_log" );
-
-sub _deprecate {
-    my ($legacy, $new) = @_;
-
-    my $impl = \&$new;
-
-    no strict 'refs';           ## no critic
-    no warnings 'redefine';     ## no critic
-    *$legacy = sub {
-        carp "$legacy() is deprecated, use $new() instead";
-        *$legacy = $impl;
-        goto &$impl;            ## no critic
-    };
-};
-
 =head1 LICENSE AND COPYRIGHT
 
 This module is part of L<Assert::Refute> suite.
