@@ -3,7 +3,7 @@ package Assert::Refute::T::Basic;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.0801;
+our $VERSION = 0.03;
 
 =head1 NAME
 
@@ -183,8 +183,7 @@ sub _like_unlike {
 
     $reg = qr#^(?:$reg)$# unless ref $reg eq 'Regexp';
         # retain compatibility with Test::More
-    return "got (undef), expecting ".($reverse ? "anything except" : "")."\n$reg"
-        if !defined $str;
+    return 'unexpected undef' if !defined $str;
     return '' if $str =~ $reg xor $reverse;
     return "$str\n".($reverse ? "unexpectedly matches" : "doesn't match")."\n$reg";
 };
@@ -254,15 +253,15 @@ sub _isa_ok {
 
 Check that a contract has been fullfilled to exactly the specified extent.
 
-See L<Assert::Refute::Exec/get_sign> for exact signature format.
+See L<Assert::Refute::Exec/signature> for exact signature format.
 
 =cut
 
 build_refute contract_is => sub {
     my ($c, $sig) = @_;
 
-    my $got = $c->get_sign;
-    return $got ne $sig && <<"EOF".$c->get_tap;
+    my $got = $c->signature;
+    return $got ne $sig && <<"EOF".$c->as_tap;
 Unexpected subcontract signature.
 Got:      $got
 Expected: $sig
